@@ -8,9 +8,9 @@ from detect_and_display_cli.detect_and_display_cli import pass_context
 def cli():
     """Manages Display."""
 
-@cli.command('display')
-@click.argument('text_input')
+@cli.command('text')
+@click.argument('input')
 @pass_context
-def display(ctx, text_input):
+def display(ctx, input):
     """Display text into screen."""
-    ctx.log(ctx.service.display(text_input))
\ No newline at end of file
+    ctx.log(ctx.service.display(input))
\ No newline at end of file
